# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2019-04-25 09:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('appid', models.CharField(max_length=30, primary_key=True, serialize=False, verbose_name='账户appid')),
                ('pri_key', models.TextField(verbose_name='私钥')),
                ('own_public_key', models.TextField(verbose_name='个人公钥')),
                ('other_public_key', models.TextField(verbose_name='对方公钥')),
                ('description', models.CharField(blank=True, max_length=50, null=True, verbose_name='账户描述')),
                ('create_time', models.DateTimeField(auto_now_add=True, verbose_name='添加时间')),
                ('is_use', models.BooleanField(default=False, verbose_name='是否启用')),
                ('account_level', models.CharField(default='1', max_length=3, verbose_name='账户等级')),
                ('Field1', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段1')),
                ('Field2', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段2')),
                ('Field3', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段3')),
            ],
            options={
                'verbose_name': 'app信息（机密）',
                'verbose_name_plural': 'app信息（机密）',
                'db_table': 'api_account',
            },
        ),
        migrations.CreateModel(
            name='AccountUseInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip', models.CharField(blank=True, max_length=50, null=True, verbose_name='ip地址')),
                ('method', models.CharField(blank=True, max_length=100, null=True, verbose_name='调用接口')),
                ('create_time', models.DateTimeField(auto_now_add=True, null=True, verbose_name='调用日期')),
                ('is_useful', models.BooleanField(default=False, verbose_name='有效调用')),
                ('Field1', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段1')),
                ('Field2', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段2')),
                ('Field3', models.CharField(blank=True, max_length=50, null=True, verbose_name='保留字段3')),
                ('app', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='comk_django_account.Account', verbose_name='账户')),
            ],
            options={
                'verbose_name': 'app调用信息',
                'verbose_name_plural': 'app调用信息',
                'db_table': 'api_useinfobyday',
            },
        ),
    ]
